==> rocketmq-all-5.2.0-source-release.zip: rocketmq-all-5.2.0-source-release/tieredstore/src/main/java/org/apache/rocketmq/tieredstore/common/SelectBufferResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.rocketmq.tieredstore.common;

import java.nio.ByteBuffer;

public class SelectBufferResult {

    private final ByteBuffer byteBuffer;
    private final long startOffset;
    private final int size;
    private final long tagCode;

    public SelectBufferResult(ByteBuffer byteBuffer, long startOffset, int size, long tagCode) {
        this.startOffset = startOffset;
        this.byteBuffer = byteBuffer;
        this.size = size;
        this.tagCode = tagCode;
    }

    public ByteBuffer getByteBuffer() {
        return byteBuffer;
    }

    public long getStartOffset() {
        return startOffset;
    }

    public int getSize() {
        return size;
    }

    public long getTagCode() {
        return tagCode;
    }
}

==> rocketmq-all-5.3.3-source-release.zip: rocketmq-all-5.3.3-source-release/tieredstore/src/main/java/org/apache/rocketmq/tieredstore/common/SelectBufferResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.rocketmq.tieredstore.common;

import java.nio.ByteBuffer;
import java.util.concurrent.atomic.AtomicLong;

public class SelectBufferResult {

    private final ByteBuffer byteBuffer;
    private final long startOffset;
    private final int size;
    private final long tagCode;
    private final AtomicLong accessCount;

    public SelectBufferResult(ByteBuffer byteBuffer, long startOffset, int size, long tagCode) {
        this.startOffset = startOffset;
        this.byteBuffer = byteBuffer;
        this.size = size;
        this.tagCode = tagCode;
        this.accessCount = new AtomicLong();
    }

    public ByteBuffer getByteBuffer() {
        return byteBuffer;
    }

    public long getStartOffset() {
        return startOffset;
    }

    public int getSize() {
        return size;
    }

    public long getTagCode() {
        return tagCode;
    }

    public AtomicLong getAccessCount() {
        return accessCount;
    }
}
